#!/usr/bin/env python3

from web_minify.minify import main

if __name__ in "__main__":
    main()
